/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.io.File;
import java.io.IOException;

import java.util.List;

/**
 * @author Michael Hashimoto
 */
public class LegacyDataArchive {

	public Commit getCommit() {
		if (_legacyDataArchiveFile.exists()) {
			List<Commit> commits = _legacyGitWorkingDirectory.log(
				1, _legacyDataArchiveFile);

			return commits.get(0);
		}

		return null;
	}

	public String getDataArchiveType() {
		return _dataArchiveType;
	}

	public File getLegacyDataArchiveFile() {
		return _legacyDataArchiveFile;
	}

	public LegacyDataArchiveUtil getLegacyDataArchiveUtil() {
		return _legacyDataArchiveUtil;
	}

	public GitWorkingDirectory getLegacyGitWorkingDirectory() {
		return _legacyGitWorkingDirectory;
	}

	public boolean isUpdated() {
		Commit commit = getCommit();

		if (commit == null) {
			return false;
		}

		Commit latestTestCommit =
			_legacyDataArchivePortalVersion.getLatestTestCommit();

		String commitMessage = commit.getMessage();

		if (commitMessage.contains(latestTestCommit.getAbbreviatedSHA())) {
			return true;
		}

		return false;
	}

	public void stageLegacyDataArchive() throws IOException {
		String dataArchiveType = _legacyDataArchiveGroup.getDataArchiveType();
		File generatedArchiveDirectory =
			_legacyDataArchiveUtil.getGeneratedArchiveDirectory();
		String portalVersion =
			_legacyDataArchivePortalVersion.getPortalVersion();

		File generatedArchiveFile = new File(
			JenkinsResultsParserUtil.combine(
				generatedArchiveDirectory.toString(), "/", portalVersion, "/",
				dataArchiveType, "-", _databaseName, ".zip"));

		if (generatedArchiveFile.exists()) {
			JenkinsResultsParserUtil.copy(
				generatedArchiveFile, _legacyDataArchiveFile);

			_legacyGitWorkingDirectory.stageFileInCurrentLocalGitBranch(
				_legacyDataArchiveFile.getCanonicalPath());
		}
	}

	protected LegacyDataArchive(
		LegacyDataArchiveGroup legacyDataArchiveGroup, String databaseName) {

		_legacyDataArchiveGroup = legacyDataArchiveGroup;
		_databaseName = databaseName;

		_legacyDataArchivePortalVersion =
			_legacyDataArchiveGroup.getLegacyDataArchivePortalVersion();

		_legacyDataArchiveUtil =
			_legacyDataArchivePortalVersion.getLegacyDataArchiveUtil();

		_legacyGitWorkingDirectory =
			_legacyDataArchiveUtil.getLegacyGitWorkingDirectory();

		_dataArchiveType = _legacyDataArchiveGroup.getDataArchiveType();
		String portalVersion =
			_legacyDataArchivePortalVersion.getPortalVersion();
		File legacyDataWorkingDirectory =
			_legacyGitWorkingDirectory.getWorkingDirectory();

		_legacyDataArchiveFile = new File(
			JenkinsResultsParserUtil.combine(
				legacyDataWorkingDirectory.toString(), "/", portalVersion,
				"/data-archive/", _dataArchiveType, "-", _databaseName,
				".zip"));
	}

	private final String _dataArchiveType;
	private final String _databaseName;
	private final File _legacyDataArchiveFile;
	private final LegacyDataArchiveGroup _legacyDataArchiveGroup;
	private final LegacyDataArchivePortalVersion
		_legacyDataArchivePortalVersion;
	private final LegacyDataArchiveUtil _legacyDataArchiveUtil;
	private final GitWorkingDirectory _legacyGitWorkingDirectory;

}