/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.io.File;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author Michael Hashimoto
 */
public abstract class RepositoryJob extends BaseJob {

	public String getBranchName() {
		if (_branchName != null) {
			return _branchName;
		}

		Matcher matcher = _jobNamePattern.matcher(getJobName());

		if (matcher.find()) {
			_branchName = matcher.group("branchName");

			return _branchName;
		}

		_branchName = "master";

		return _branchName;
	}

	public GitWorkingDirectory getGitWorkingDirectory() {
		if (gitWorkingDirectory != null) {
			return gitWorkingDirectory;
		}

		checkRepositoryDir();

		gitWorkingDirectory = GitWorkingDirectoryFactory.newGitWorkingDirectory(
			getBranchName(), repositoryDir.getAbsolutePath());

		return gitWorkingDirectory;
	}

	public void setRepositoryDir(File repositoryDir) {
		if (this.repositoryDir != null) {
			throw new IllegalStateException(
				"Repository directory is already set to " +
					this.repositoryDir.getPath());
		}

		this.repositoryDir = repositoryDir;
	}

	protected RepositoryJob(String jobName) {
		super(jobName);
	}

	protected void checkRepositoryDir() {
		if (repositoryDir == null) {
			throw new IllegalStateException("Repository directory is not set");
		}

		if (!repositoryDir.exists()) {
			throw new IllegalStateException(
				repositoryDir.getPath() + " does not exist");
		}
	}

	protected GitWorkingDirectory gitWorkingDirectory;
	protected File repositoryDir;

	private static final Pattern _jobNamePattern = Pattern.compile(
		"[^\\(]+\\((?<branchName>[^\\)]+)\\)");

	private String _branchName;

}